@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from enum import Enum
-from .sse import _runSSE
+from .sse import _runSSE, _runSSEAsync
 
 
 class FXSSE(Enum):
@@ -11,19 +11,30 @@ class FXSSE(Enum):
         return list(map(lambda c: c.value, FXSSE))
 
 
-# def _runSSE(method='', symbols=None, on_data=None, token='', version=''):
-
-
 def fxSSE(symbols=None, on_data=None, token='', version=''):
     '''This endpoint streams real-time foreign currency exchange rates.
 
     https://iexcloud.io/docs/api/#forex-currencies
 
     Args:
-        symbols (string); Tickers to request
+        symbols (str): Tickers to request
         on_data (function): Callback on data
-        token (string); Access token
-        version (string); API version
+        token (str): Access token
+        version (str): API version
 
     '''
     return _runSSE('forex', symbols, on_data, token, version)
+
+
+async def fxSSEAsync(symbols=None, token='', version=''):
+    '''This endpoint streams real-time foreign currency exchange rates.
+
+    https://iexcloud.io/docs/api/#forex-currencies
+
+    Args:
+        symbols (str): Tickers to request
+        token (str): Access token
+        version (str): API version
+    '''
+    async for item in _runSSEAsync('forex', symbols, token, version):
+        yield item
