@@ -1,6 +1,7 @@
 
 # -*- coding: utf-8 -*-
 import pandas as pd
+from functools import wraps
 from ..common import _getJson, _raiseIfNotStr, _toDatetime
 
 
@@ -11,13 +12,13 @@ def optionExpirations(symbol, token='', version='', filter=''):
     9:30am-5pm ET Mon-Fri
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/options', token, version, filter)
@@ -30,15 +31,15 @@ def options(symbol, expiration, side='', token='', version='', filter=''):
     9:30am-5pm ET Mon-Fri
 
     Args:
-        symbol (string); Ticker to request
-        expiration (string); Expiration date
-        side (string); Side (optional)
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        expiration (str): Expiration date
+        side (str): Side (optional)
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     if side:
@@ -46,23 +47,8 @@ def options(symbol, expiration, side='', token='', version='', filter=''):
     return _getJson('stock/{symbol}/options/{expiration}/'.format(symbol=symbol, expiration=expiration), token, version, filter)
 
 
+@wraps(options)
 def optionsDF(symbol, expiration, side='', token='', version='', filter=''):
-    '''Returns end of day options data
-
-    https://iexcloud.io/docs/api/#options
-    9:30am-5pm ET Mon-Fri
-
-    Args:
-        symbol (string); Ticker to request
-        expiration (string); Expiration date
-        side (string); Side (optional)
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     p = options(symbol, expiration, side, token, version, filter)
     df = pd.DataFrame(p)
     _toDatetime(df)
