@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import pandas as pd
+from functools import wraps
 from ..common import _expire, _getJson
 
 
@@ -11,30 +12,18 @@ def exchanges(token='', version='', filter=''):
     8am, 9am, 12pm, 1pm UTC daily
 
     Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     return _getJson('ref-data/market/us/exchanges', token, version, filter)
 
 
+@wraps(exchanges)
 def exchangesDF(token='', version='', filter=''):
-    '''Returns an array of U.S. exchanges.
-
-    https://iexcloud.io/docs/api/#u-s-exchanges
-    8am, 9am, 12pm, 1pm UTC daily
-
-    Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     return pd.DataFrame(exchanges(token, version, filter))
 
 
@@ -46,28 +35,16 @@ def internationalExchanges(token='', version='', filter=''):
     8am, 9am, 12pm, 1pm UTC daily
 
     Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     return _getJson('ref-data/exchanges', token, version, filter)
 
 
+@wraps(internationalExchanges)
 def internationalExchangesDF(token='', version='', filter=''):
-    '''Returns an array of U.S. exchanges.
-
-    https://iexcloud.io/docs/api/#international-exchanges
-    8am, 9am, 12pm, 1pm UTC daily
-
-    Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     return pd.DataFrame(internationalExchanges(token, version, filter))
