@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import pandas as pd
+from functools import wraps
 from ..common import _expire, _getJson
 
 
@@ -10,29 +11,18 @@ def sectors(token='', version='', filter=''):
     https://iexcloud.io/docs/api/#sectors
 
     Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     return _getJson('ref-data/sectors', token, version, filter)
 
 
+@wraps(sectors)
 def sectorsDF(token='', version='', filter=''):
-    '''Returns an array of sectors.
-
-    https://iexcloud.io/docs/api/#sectors
-
-    Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     return pd.DataFrame(sectors(token, version, filter))
 
 
@@ -43,27 +33,16 @@ def tags(token='', version='', filter=''):
     https://iexcloud.io/docs/api/#tags
 
     Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     return _getJson('ref-data/tags', token, version, filter)
 
 
+@wraps(tags)
 def tagsDF(token='', version='', filter=''):
-    '''Returns an array of tags.
-
-    https://iexcloud.io/docs/api/#tags
-
-    Args:
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     return pd.DataFrame(tags(token, version, filter))
