@@ -12,11 +12,11 @@ def bonusIssue(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#bonus-issue
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -42,11 +42,11 @@ def distribution(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#distribution
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -72,11 +72,11 @@ def returnOfCapital(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#return-of-capital
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -102,11 +102,11 @@ def rightsIssue(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#rights-issue
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -132,11 +132,11 @@ def rightToPurchase(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#right-to-purchase
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -162,11 +162,11 @@ def securityReclassification(symbol='', refid='', token='', version='', filter='
     https://iexcloud.io/docs/api/#security-reclassification
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -192,11 +192,11 @@ def securitySwap(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#security-swap
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -222,11 +222,11 @@ def spinoff(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#spinoff
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
@@ -252,11 +252,11 @@ def splits(symbol='', refid='', token='', version='', filter=''):
     https://iexcloud.io/docs/api/#splits
 
     Args:
-        symbol (string); Symbol to look up
-        refid (string); Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Symbol to look up
+        refid (str): Optional. Id that matches the refid field returned in the response object. This allows you to pull a specific event for a symbol.
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict or DataFrame: result
