@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import requests
 import pandas as pd
+from functools import wraps
 from IPython.display import Image as ImageI
 from io import BytesIO
 from PIL import Image as ImageP
@@ -15,13 +16,13 @@ def company(symbol, token='', version='', filter=''):
     Updates at 4am and 5am UTC every day
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/company', token, version, filter)
@@ -35,21 +36,8 @@ def _companyToDF(c, token='', version='', filter=''):
     return df
 
 
+@wraps(company)
 def companyDF(symbol, token='', version='', filter=''):
-    '''Company reference data
-
-    https://iexcloud.io/docs/api/#company
-    Updates at 4am and 5am UTC every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     c = company(symbol, token, version, filter)
     df = _companyToDF(c)
     return df
@@ -63,33 +51,20 @@ def insiderRoster(symbol, token='', version='', filter=''):
     Updates at 5am, 6am ET every day
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/insider-roster', token, version, filter)
 
 
+@wraps(insiderRoster)
 def insiderRosterDF(symbol, token='', version='', filter=''):
-    '''Returns the top 10 insiders, with the most recent information.
-
-    https://iexcloud.io/docs/api/#insider-roster
-    Updates at 5am, 6am ET every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     val = insiderRoster(symbol, token, version, filter)
     df = pd.DataFrame(val)
     _toDatetime(df, cols=[], tcols=['reportDate'])
@@ -104,33 +79,20 @@ def insiderSummary(symbol, token='', version='', filter=''):
     Updates at 5am, 6am ET every day
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/insider-summary', token, version, filter)
 
 
+@wraps(insiderSummary)
 def insiderSummaryDF(symbol, token='', version='', filter=''):
-    '''Returns aggregated insiders summary data for the last 6 months.
-
-    https://iexcloud.io/docs/api/#insider-summary
-    Updates at 5am, 6am ET every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     val = insiderSummary(symbol, token, version, filter)
     df = pd.DataFrame(val)
     _toDatetime(df)
@@ -145,33 +107,20 @@ def insiderTransactions(symbol, token='', version='', filter=''):
     Updates at UTC every day
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/insider-transactions', token, version, filter)
 
 
+@wraps(insiderTransactions)
 def insiderTransactionsDF(symbol, token='', version='', filter=''):
-    '''Returns insider transactions.
-
-    https://iexcloud.io/docs/api/#insider-transactions
-    Updates at UTC every day
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     val = insiderTransactions(symbol, token, version, filter)
     df = pd.DataFrame(val)
     _toDatetime(df)
@@ -186,10 +135,10 @@ def logo(symbol, token='', version='', filter=''):
     8am UTC daily
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         dict: result
@@ -206,10 +155,10 @@ def logoPNG(symbol, token='', version='', filter=''):
     8am UTC daily
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         image: result as png
@@ -227,10 +176,10 @@ def logoNotebook(symbol, token='', version='', filter=''):
     8am UTC daily
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
         image: result
@@ -248,13 +197,13 @@ def peers(symbol, token='', version='', filter=''):
     8am UTC daily
 
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/peers', token, version, filter)
@@ -269,21 +218,8 @@ def _peersToDF(p):
     return df
 
 
+@wraps(peers)
 def peersDF(symbol, token='', version='', filter=''):
-    '''Peers of ticker
-
-    https://iexcloud.io/docs/api/#peers
-    8am UTC daily
-
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     p = peers(symbol, token, version, filter)
     df = _peersToDF(p)
     return df
@@ -295,31 +231,20 @@ def relevant(symbol, token='', version='', filter=''):
 
     https://iexcloud.io/docs/api/#relevant
     Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
+        symbol (str): Ticker to request
+        token (str): Access token
+        version (str): API version
+        filter (str): filters: https://iexcloud.io/docs/api/#filter-results
 
     Returns:
-        dict: result
+        dict or DataFrame: result
     '''
     _raiseIfNotStr(symbol)
     return _getJson('stock/' + symbol + '/relevant', token, version, filter)
 
 
+@wraps(relevant)
 def relevantDF(symbol, token='', version='', filter=''):
-    '''Same as peers
-
-    https://iexcloud.io/docs/api/#relevant
-    Args:
-        symbol (string); Ticker to request
-        token (string); Access token
-        version (string); API version
-        filter (string); filters: https://iexcloud.io/docs/api/#filter-results
-
-    Returns:
-        DataFrame: result
-    '''
     df = pd.DataFrame(relevant(symbol, token, version, filter))
     _toDatetime(df)
     return df
